Welcome to hasasia's documentation!
======================================
.. include:: ../README.rst
  :end-before: Getting Started
  
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   sensitivity_tutorial
   skymap_tutorial
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
